<?php

/**
 * @file
 * Drush wrapper around SCSSPHP.
 */

/**
 * Implementation of hook_drush_command().
 */
function scssphp_drush_command() {
  $items['scssphp'] = array(
    'description' => 'Compiles SCSS files into CSS files.',
    'arguments' => array(
      'file' => 'SCSS file to compile to CSS.',
      'output' => 'Destination for the new SCSS file. Defaults to <file>.css.',
    ),
    'examples' => array(
      'drush scssphp example.scss' => 'Compiles example.scss to example.css.',
    ),
    'bootstrap' => DRUSH_BOOTSTRAP_DRUSH,
  );
  return $items;
}

/**
 * Drush callback; Executes on "drush scssphp" commands.
 */
function drush_scssphp($file = '', $output = '') {
  if (empty($file)) {
    drush_log(dt('The <file> argument is required.'), 'error');
  }
  if (!file_exists($file)) {
    drush_log(dt('Input <file> does not exist.'), 'error');
  }

  // Load the SCSSPHP library.
  require_once(__DIR__ . '/vendor/leafo/scssphp/scss.inc.php');

  // Make sure output is availble.
  if (empty($output)) {
    $output = $file . '.css';
  }

  // Compile the SCSS to CSS.
  $contents = file_get_contents($file);
  $scss = new scssc();
  $scss->addImportPath(dirname($file));
  $data = $scss->compile($contents);
  return file_put_contents($output, $data);
}
